@@ -1,8 +1,7 @@
 import src.jadecobra
 import src.jadecobra.tester
 import src.jadecobra.toolkit
-import jadecobra.versioning
-import os
+import src.jadecobra.versioning
 
 
 class TestJadeCobraToolkit(src.jadecobra.tester.TestCase):
@@ -26,11 +25,16 @@ class TestJadeCobraToolkit(src.jadecobra.tester.TestCase):
                 'file_exists',
                 'get_commit_message',
                 'header',
+                'json',
                 'log_performance',
                 'logger',
-                'make_dir',
+                'make_parent_directory',
                 'os',
                 'pathlib',
+                'publish',
+                'read_json',
+                'run_in_shell',
+                'subprocess',
                 'time',
                 'time_it',
                 'to_camel_case',
